@@ -14,6 +14,8 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
+from __future__ import print_function
+from __future__ import absolute_import
 import dbus
 import dbus.service
 import dbus.mainloop.glib
@@ -23,22 +25,25 @@ import time, sys
 import calculate.contrib
 from suds import MethodNotFound
 import os, pwd, shutil
-import ConfigParser
+# import ConfigParser
+import calculate.lib.configparser as ConfigParser
 
-from TrayIcon import TrayIcon
 
-from more import get_sid, get_view_params, _print, get_icon, get_system_rgb, \
+from .TrayIcon import TrayIcon
+
+from .more import get_sid, get_view_params, _print, get_icon, get_system_rgb, \
     dpivalue
     
-from MainClass import ApiClient
+from .MainClass import ApiClient
 from calculate.consolegui.datavars import DataVarsGui
-from pid_information import client_pid_info
+from .pid_information import client_pid_info
 #from calculate.lib.cl_lang import setLocalTranslate
 #setLocalTranslate('console_gui',sys.modules[__name__])
-
+import gettext
+_ = gettext.gettext
 class SelectedMethodWgt(qt.QWidget):
     def __init__(self, app, args):
-        qt.QWidget.__init__(self)
+        super().__init__()
         self.args = args
         self.user_changed_flag = False
         self.lang = args.lang
@@ -100,7 +105,7 @@ class SelectedMethodWgt(qt.QWidget):
             _print('Method not found: ', self.args.method + '_view')
             self.close()
             sys.exit(1)
-        if self.ClientObj.method_names.has_key(self.args.method):
+        if self.args.method in self.ClientObj.method_names:
             view_method = self.ClientObj.method_names[self.args.method]
         else:
             view_method = self.args.method
@@ -119,7 +124,7 @@ class SelectedMethodWgt(qt.QWidget):
         pass
 
     def has_update(self, update):
-        print "Update", update
+        print("Update", update)
 
     def get_size(self):
         self.config = ConfigParser.ConfigParser()
@@ -168,7 +173,7 @@ class SelectedMethodWgt(qt.QWidget):
         else:
             reply = self.show_close_messagebox()
 
-        from mainframe import MainFrame
+        from .mainframe import MainFrame
         if reply == qt.QMessageBox.Yes:
             if hasattr (self, 'con_lost_lbl'):
                 self.con_lost_lbl.hide()
@@ -186,8 +191,7 @@ class SelectedMethodWgt(qt.QWidget):
                 self.ClientObj.client.service.pid_kill(pid, self.ClientObj.sid)
                 while True:
                     client_pid_info(self.ClientObj, self.ClientObj.client, 0)
-                    if not self.ClientObj.process_dict[str(pid)].has_key \
-                                                                ('status'):
+                    if 'status' not in self.ClientObj.process_dict[str(pid)]:
                         return 1
                     if self.ClientObj.process_dict[str(pid)]['status'] != '1':
                         return 1
@@ -200,7 +204,7 @@ class SelectedMethodWgt(qt.QWidget):
 
     def show_close_messagebox(self):
         msgBox = qt.QMessageBox(self)
-        if self.ClientObj.method_names.has_key(self.method):
+        if self.method in self.ClientObj.method_names:
             method_name = self.ClientObj.method_names[self.method]
         else:
             method_name = self.method
@@ -222,16 +226,19 @@ class SelectedMethodWgt(qt.QWidget):
 
 def parse():
     import gettext
+    import locale
     try:
-        set_lang = gettext.locale.getdefaultlocale()[0][:2]
+        # set_lang = gettext.locale.getdefaultlocale()[0][:2]
+        set_lang = locale.getdefaultlocale()[0][:2]
         lang = gettext.translation('cl_consolegui3', languages=[set_lang],fallback=True)
         try:
-            lang.install(unicode=True)
+            lang.install()
+            # lang.install(unicode=True)
         except UnboundLocalError:
             pass
     except (IOError, TypeError):
         pass
-
+    _ = gettext.gettext
     import argparse
     parser = argparse.ArgumentParser(add_help=False)
     parser.add_argument(
@@ -258,7 +265,7 @@ def parse():
 
 class MyTabBar(qt.QTabBar):
     def __init__(self, _parent):
-        qt.QTabBar.__init__(self)
+        super().__init__()
         self._parent = _parent
 
     def wheelEvent(self, event):
@@ -273,7 +280,7 @@ class MyTabBar(qt.QTabBar):
 
 class ToolTabWidget(qt.QTabWidget):
     def __init__(self, app, args = None, host = None, port = None):
-        qt.QTabWidget.__init__(self)
+        super().__init__()
         self.app = app
         if args:
             if args.lang:
@@ -495,7 +502,7 @@ class ToolTabWidget(qt.QTabWidget):
 
     def translate(self, lang = None):
         self.new_con_txt = _('New connection')
-        self.new_con_txt = self.new_con_txt.decode('utf-8')
+        # self.new_con_txt = self.new_con_txt.decode('utf-8')
 
         current = self.currentIndex()
         # not add if exists clean tab
@@ -518,7 +525,7 @@ class ToolTabWidget(qt.QTabWidget):
 
     def find_host(self, host_name, port):
         ind = self.currentIndex()
-        for i in xrange (self.count() - 1):
+        for i in range (self.count() - 1):
             self.setCurrentIndex(i)
             wgt = self.currentWidget()
             if hasattr (wgt, 'ClientObj'):
@@ -561,7 +568,7 @@ class ToolTabWidget(qt.QTabWidget):
             size = self.config.get('gui', 'size')
         except (ConfigParser.NoOptionError, ConfigParser.NoSectionError):
             return False
-        tup_size = map(lambda x: int(x), size.split(','))
+        tup_size = list(map(lambda x: int(x), size.split(',')))
         self.resize(tup_size[0], tup_size[1])
         return True
 
