@@ -14,8 +14,9 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
+from __future__ import absolute_import
 from calculate.consolegui import qt
-from more import ButtonMenu, icon_visible, LabelWordWrap, get_sid, show_msg, \
+from .more import ButtonMenu, icon_visible, LabelWordWrap, get_sid, show_msg, \
                  ClientServiceThread, show_question, get_view_params, _print, \
     get_system_rgb, dpivalue
 
@@ -23,7 +24,7 @@ from more import ButtonMenu, icon_visible, LabelWordWrap, get_sid, show_msg, \
 class StepLabel(qt.QLabel):
     clicked = qt.Signal()
     def __init__(self, text, parent):
-        qt.QLabel.__init__(self, parent)
+        super().__init__(parent)
         self.setWordWrap(True)
         self.setText(text)
         self.updateGeometry()
@@ -47,7 +48,7 @@ class StepLabel(qt.QLabel):
 
 class LeftMenu(qt.QScrollArea):
     def __init__(self, parent, ClientObj):
-        qt.QScrollArea.__init__(self, parent)
+        super().__init__(parent)
         self._parent = parent
         self.ClientObj = ClientObj
 
@@ -125,7 +126,7 @@ class LeftMenu(qt.QScrollArea):
 #                    pass
                 attrubute_list = []
                 sub_group_list = []
-                if self.button_list.has_key(sub_group):
+                if sub_group in self.button_list:
                     attrubute_list = self.button_list[sub_group][0]
                     sub_group_list = self.button_list[sub_group][1]
                 self.button_list[sub_group] = []
@@ -152,7 +153,7 @@ class LeftMenu(qt.QScrollArea):
                 pass
             Button = ButtonMenu(groups[i], groups[i + 1], groups[i + 2], self)
             Button.clicked.connect(self.onActivated)
-            if not self.button_list.has_key(sub_groups[num]):
+            if sub_groups[num] not in self.button_list:
                 self.button_list[sub_groups[num]] = []
             self.button_list[sub_groups[num]].append(Button)
         
@@ -180,8 +181,7 @@ class LeftMenu(qt.QScrollArea):
 
     def groupActivated(self, groups, sub_group, title, ClientObj, back = False):
         ClientObj.MainWidget.delete_MainFrameWgt()
-        ClientObj.MainWidget.MainFrameWgt = qt.QWidget \
-                                                    (ClientObj.MainWidget)
+        ClientObj.MainWidget.MainFrameWgt = qt.QWidget(ClientObj.MainWidget)
 
         hlayout = qt.QHBoxLayout()
         hlayout.addItem(qt.QSpacerItem( 0, 0, \
@@ -207,7 +207,8 @@ class LeftMenu(qt.QScrollArea):
         # set new Title
         new_title = self.sender().text()
         try:
-            new_title = new_title.decode('utf-8')
+            # new_title = new_title.decode('utf-8')
+            new_title = new_title
         except (UnicodeDecodeError, UnicodeEncodeError):
             pass
         self._parent.ClientObj._parent.setWindowTitle \
@@ -219,7 +220,7 @@ class LeftMenu(qt.QScrollArea):
         self._parent.ClientObj.sid = \
                                 get_sid(self._parent.ClientObj.client)
         # switch to the desired step
-        if self._parent.ClientObj.param_objects.has_key(method_name):
+        if method_name in self._parent.ClientObj.param_objects:
             self._parent.ClientObj.param_objects[method_name]['step'] = step
 
         # Call server method
@@ -237,16 +238,17 @@ class LeftMenu(qt.QScrollArea):
 
     def onActivated_after(self, view):
         if type(view) == Exception:
-            if hasattr (view.message, 'message'):
-                view = view.message
+            # if hasattr (view.message, 'message'):
+            #     view = view.message
 
-            if type(view.message) == tuple:
-                if view.message[0] == 403:
-                    msg = _('Permission denied')
-                else:
-                    msg = ' '.join(map(lambda x: str(x), view.message))
-            else:
-                msg = view.message.__str__()
+            # if type(view.message) == tuple:
+            #     if view.message[0] == 403:
+            #         msg = _('Permission denied')
+            #     else:
+            #         msg = ' '.join(map(lambda x: str(x), view.message))
+            # else:
+            #     msg = view.message.__str__()
+            msg = str(view)
             show_msg(msg)
             return 1
 
