@@ -14,6 +14,8 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
+from __future__ import print_function
+from __future__ import absolute_import
 from calculate.consolegui import qt
 
 DEBUG_LEVEL = 0
@@ -21,23 +23,24 @@ DEBUG_LEVEL = 0
 def debug(level, *args):
     if level <= DEBUG_LEVEL:
         for s in args:
-            print s,
-        print
-import urllib2
+            print(s, end=' ')
+        print()
 import calculate.contrib
+from urllib.error import URLError
 from suds import MethodNotFound
 import re
 
-from calculate.core.client.function import switch, create_obj
+
 from calculate.lib.utils.colortext.converter import XmlConverter
 from calculate.lib.utils.colortext.output import SpanCssOutput
 from calculate.lib.utils.tools import imap_regexp
-from more import WorkPalette, ParameterWindow, get_system_rgb
+from .utils import switch, create_obj
+from .more import WorkPalette, ParameterWindow, get_system_rgb
 
-from more import get_sid, ClientServiceThread, show_msg, TaskWidget, ErrorWgt,\
+from .more import get_sid, ClientServiceThread, show_msg, TaskWidget, ErrorWgt,\
                  ResultLayout, get_view_params, get_icon, dpivalue
-from more import LabelWordWrap as Label
-from SelectTable import SelectedTableWidget
+from .more import LabelWordWrap as Label
+from .SelectTable import SelectedTableWidget
 
 class LabelWordWrap(Label):
     def __init__(self, name, parent=None, mono=False, margin_top=0):
@@ -48,7 +51,7 @@ class LabelWordWrap(Label):
 
 class PlusButton(qt.QPushButton):
     def __init__(self, parent, ClientObj, method, disable_method=None):
-        qt.QPushButton.__init__(self, parent)
+        super().__init__(parent)
         icon = get_icon('list-add')
         if not icon.isNull():
             self.setIcon(icon)
@@ -76,7 +79,7 @@ class PlusButton(qt.QPushButton):
         self.get_Frame_thread.start()
 
     def after_call(self, view):
-        if self.ClientObj.method_names.has_key(self.method):
+        if self.method in self.ClientObj.method_names:
             view_method = self._parent.ClientObj.method_names[self.method]
         else:
             view_method = self.method
@@ -88,8 +91,7 @@ class MainFrameRes(qt.QWidget):
     valSignal = qt.Signal()
     def __init__(self, parent, ClientObj, method_name, meth_result,
                  change_offset=False):
-#        super(MainFrameRes, self).__init__(self, parent)
-        qt.QWidget.__init__(self, parent)
+        super().__init__(parent)
         self._parent = parent
         self.ClientObj = ClientObj
         self.method_name = method_name
@@ -113,8 +115,9 @@ class MainFrameRes(qt.QWidget):
 
         self._parent.methodname_wgt.show()
         self._parent.control_button.show()
-        self._parent.control_button.del_button()
-        if self.ClientObj.method_names.has_key(self.method_name):
+        #DEBUG    
+        # self._parent.control_button.del_button()
+        if self.method_name in self.ClientObj.method_names:
             self._parent.methodname_wgt.setMethodName \
                     (self.ClientObj.method_names[self.method_name])
         else:
@@ -256,10 +259,10 @@ class MainFrameRes(qt.QWidget):
                                        table.onClick + '_view', step = 0) #int(table.step) if table.step else 0)
                 view = self.client.service[0][table.onClick + '_view'](
                     sid, view_params)
-            except MethodNotFound, e:
+            except MethodNotFound as e:
                 _print(e)
                 return
-            if self._parent.ClientObj.method_names.has_key(table.onClick):
+            if table.onClick in self._parent.ClientObj.method_names:
                 view_method = self._parent.ClientObj.method_names \
                                                         [table.onClick]
             else:
@@ -716,7 +719,6 @@ class MainFrameRes(qt.QWidget):
         """
         Exception container with URLError
         """
-        from urllib2 import URLError
         from socket import error as socket_error
         try:
             if (exception.args and type(exception.args[0]) == URLError and
@@ -783,12 +785,11 @@ class MainFrameRes(qt.QWidget):
     def get_entire_frame(self, pid = None):
         """ get entire frame, from beginning (if client disconnected) """
         self.ClientObj.app.processEvents()
-
         sid = get_sid(self.ClientObj.client)
         if not pid:
             try:
                 list_pid = self.ClientObj.client.service.list_pid(sid = sid)
-            except urllib2.URLError, e:
+            except URLError as e:
                 _print ('get_entire_frame in MainFrameResult Exception')
                 show_msg (e, _("Not connected!"))
                 return 1
@@ -951,7 +952,7 @@ class MainFrameRes(qt.QWidget):
     def get_Table(self, sid, pid, item):
         try:
             table = self.ClientObj.client.service.get_table(sid, pid, item.id)
-        except urllib2.URLError:
+        except URLError:
             self.show_error('Error get table from server')
             return 1
 
@@ -1031,7 +1032,7 @@ class MainFrameRes(qt.QWidget):
 class MessageDialog(qt.QWidget):
     # answer to the server question
     def __init__(self, parent, item, sid, pid, isPassword = False):
-        super(MessageDialog, self).__init__()
+        super().__init__()
         self._parent = parent
 #        self.item = item
         self.sid = sid
@@ -1110,7 +1111,7 @@ class ButtonDialog(qt.QWidget):
     button_size = 144
 
     def __init__(self, parent, item, sid, pid):
-        super(ButtonDialog, self).__init__()
+        super().__init__()
         self._parent = parent
         self.sid = sid
         self.pid = pid
