@@ -14,28 +14,24 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
+# from __future__ import absolute_import
 from calculate.consolegui import qt
 
-from pid_information import client_list_pid, client_pid_info
-from more import LabelWordWrap, show_msg, get_sid, ClientServiceThread
-
+from .pid_information import client_list_pid, client_pid_info
+from .more import LabelWordWrap, show_msg, get_sid, ClientServiceThread
 class ViewProc(qt.QWidget):
-    
     def __init__(self, parent, ClientObj):
-#        super(ViewProc, self).__init__(parent)
-        qt.QWidget.__init__(self, parent)
-#        self._parent = parent
+        super().__init__(parent)
         self.ClientObj = ClientObj
         self.client = ClientObj.client
         self.pid = 0
         client_pid_info(ClientObj, ClientObj.client, 0)
         list_pid = client_list_pid(self.ClientObj.client)
-
         ClientObj._parent.setWindowTitle (
                             _('View information about the running processes')\
                             + ' - ' + self.ClientObj.Name)
         
-        self.lable_list = []
+        self.label_list = []
         self.button_list = []
         self.status_list = []
         self.grid_layout = qt.QGridLayout()
@@ -50,16 +46,16 @@ class ViewProc(qt.QWidget):
             #if list_pid[num] == ClientObj._parent.sys_update_pid:
             #    continue
             # add method name
-            if self.ClientObj.process_dict[str(list_pid[num])].has_key \
-                                                             ('method_name'):
+            if 'method_name' in self.ClientObj.process_dict[str(list_pid[num])]:
                 method_name = self.ClientObj.process_dict[str(list_pid[num])] \
                                                               ['method_name']
             else:
                 method_name = self.ClientObj.process_dict[str(list_pid[num])] \
                                                                      ['name']
-
-            if self.ClientObj.method_names.has_key(method_name):
-                view_method_name = self.ClientObj.method_names[method_name]
+            method_name = str(method_name)
+            if method_name in self.ClientObj.method_names:
+                view_method_name = str(self.ClientObj.method_names[method_name])
+            
 #            try:
 #                view_method_name = self.ClientObj.param_objects \
 #                                            [method_name]['view_method_name']
@@ -67,13 +63,13 @@ class ViewProc(qt.QWidget):
             else:
                 view_method_name = method_name
             
-            try:
-                view_method_name = view_method_name.encode('utf-8')
-            except (UnicodeEncodeError, UnicodeDecodeError):
-                pass
+            # try:
+            #     view_method_name = view_method_name.encode('utf-8')
+            # except (UnicodeEncodeError, UnicodeDecodeError):
+            #     pass
 
-            self.lable_list.append(LabelWordWrap(str(view_method_name), self))
-            self.grid_layout.addWidget(self.lable_list[num], num+2,0)
+            self.label_list.append(LabelWordWrap(str(view_method_name), self))
+            self.grid_layout.addWidget(self.label_list[num], num+2,0)
             
             # add start time process
             # del mircosec
@@ -135,15 +131,16 @@ class ViewProc(qt.QWidget):
             for i in self.ClientObj.process_dict:
                 if i == pid:
                     # set new window title
-                    n = method_name
-                    try:
-                        name = n.decode('utf-8')
-                    except (UnicodeEncodeError, UnicodeDecodeError):
-                        pass
+                    name = method_name
+                    # n = method_name
+                    # try:
+                    #     # name = n.decode('utf-8')
+                    #     name = n
+                    # except (UnicodeEncodeError, UnicodeDecodeError):
+                    #     pass
                     self.ClientObj._parent.setWindowTitle \
                                     (self.ClientObj._parent.windowTitle() +
                                     ' - ' + name)
-
     #                try:
     #                    self.ClientObj.process_dict[i]['result']
     #                except:
