@@ -14,15 +14,16 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
+from __future__ import absolute_import
 import socket
 from calculate.consolegui import qt
 
-from more import LabelWordWrap, show_msg, get_icon
+from .more import LabelWordWrap, show_msg, get_icon
 
 def passphrase_callback(v):
     if type(v) == int or not v:
         return ""
-    return str(v)
+    return bytes(v, "UTF-8")
 
 def generateRSAKey():
     from M2Crypto import RSA, m2
@@ -36,7 +37,7 @@ def makePKey(key):
 
 class RequestCreate (qt.QWidget):
     def __init__(self, parent, ClientObj, key, cert_path, server_host_name):
-        qt.QWidget.__init__(self)
+        super().__init__()
         self.ClientObj = ClientObj
         self._parent = parent
 
@@ -61,7 +62,8 @@ class RequestCreate (qt.QWidget):
         username = ClientObj.VarsApi.Get('ur_fullname')
         suffixPort = ":%s"%ClientObj.VarsApi.Get('core.cl_core_port')
 
-        username = username.decode('utf-8')
+        # username = username.decode('utf-8')
+        username = username
         self.mainlayout.addWidget(LabelWordWrap(_('User Name'), self),1,0,
                                                 qt.Qt.AlignRight)
         self.user_name = qt.QLineEdit(username, self)
@@ -147,15 +149,15 @@ class RequestCreate (qt.QWidget):
         private_key_passwd = self.passwd_lineedit.text()
         rsa = generateRSAKey()
         rsa.save_key(self.key + '_pub', cipher = None,
-                     callback = lambda *unused: "")
+                     callback = lambda *unused: b"")
 
         pkey = makePKey(rsa)
         if not passphrase_callback(private_key_passwd):
             pkey.save_key(self.key, cipher = None,
-                          callback = lambda *unused: "")
+                          callback = lambda *unused: b"")
         else:
             pkey.save_key(self.key,\
-                            callback= lambda *unused: str(private_key_passwd))
+                            callback= lambda *unused: bytes(private_key_passwd, "UTF-8"))
 #########################################
         req = X509.Request()
         req.set_version(req.get_version())
@@ -181,7 +183,8 @@ class RequestCreate (qt.QWidget):
         req.add_extensions(extstack)
         req.sign(pkey, 'md5')
 #########################################
-        crtreq = req.as_pem()
+        
+        crtreq = str(req.as_pem(), 'utf-8')
         crtfile = open(self.cert_path + '/%s.csr' %self.server_host_name, 'w')
         crtfile.write(crtreq)
         crtfile.close()
