@@ -14,11 +14,12 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
+from __future__ import absolute_import
 from calculate.consolegui import qt
-import urllib2
+import urllib.request as urllib2
 from calculate.lib.utils.tools import Locker
 
-from more import show_msg, LabelWordWrap, get_ip_mac, get_sid, get_icon, dpivalue
+from .more import show_msg, LabelWordWrap, get_ip_mac, get_sid, get_icon, dpivalue
 
 def client_sid(sid, client, cert_id, lang):
     """ get number session from server and write this in file """
@@ -75,7 +76,7 @@ def client_post_cert (client, lang):
 
 class ViewSessionInfo (qt.QWidget):
     def __init__(self, parent, client, window):
-        qt.QWidget.__init__(self)
+        super().__init__()
         self.layout = qt.QGridLayout()
 
         sid = get_sid(client)
@@ -145,7 +146,7 @@ class ViewSessionInfo (qt.QWidget):
         def wrapper():
             try:
                 res = client.service.clear_session_cache(sid)
-            except Exception, e:
+            except Exception as e:
                 show_msg(e, 'Error')
                 return 1
             if res:
